import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/components/SCIAppTheme.dart';
import 'package:sci_mobile_components/src/components/SCIBody.dart';
import 'package:sci_mobile_components/src/models/theme_model.dart';

class SCIAppBar extends StatelessWidget implements PreferredSizeWidget {
  final double height;
  final Image logo;
  final VoidCallback onSettingPressed;
  final VoidCallback onNotificationPressed;
  final int notificationCount;

  SCIAppBar({
    this.height = 60.0,
    this.logo,
    this.onSettingPressed,
    this.onNotificationPressed,
    this.notificationCount = 0,
  });

  @override
  Widget build(BuildContext context) {
    // Extract theme properties from top level SCIAppTheme
    final SCIThemeModel theme = SCIAppTheme.of(context).theme;

    return Container(
      color: theme.lightColor,
      child: SafeArea(
        child: SCIBody(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              logo,
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  // TODO: Future Implementation
                  // NotificationButton(
                  //   onNotificationPressed: onNotificationPressed,
                  //   notificationCount: notificationCount,
                  // ),
                  IconButton(
                    icon: Icon(Icons.settings),
                    onPressed: onSettingPressed,
                    iconSize: 24.0,
                    color: theme.darkColor,
                  ),
                ],
              )
            ],
          ),
        ),
      ),
    );
  }

  @override
  Size get preferredSize => Size.fromHeight(height);
}

class NotificationButton extends StatelessWidget {
  final VoidCallback onNotificationPressed;
  final int notificationCount;

  const NotificationButton({
    Key key,
    @required this.onNotificationPressed,
    @required this.notificationCount,
  });

  @override
  Widget build(BuildContext context) {
    final SCIThemeModel theme = SCIAppTheme.of(context).theme;

    return Stack(
      children: <Widget>[
        IconButton(
          icon: Icon(Icons.notifications),
          onPressed: onNotificationPressed,
          iconSize: 24.0,
          color: theme.darkColor,
        ),
        notificationCount != 0
            ? Positioned(
                right: 11,
                top: 11,
                child: Container(
                  padding: EdgeInsets.all(2),
                  decoration: BoxDecoration(
                    color: Colors.red,
                    borderRadius: BorderRadius.circular(6),
                  ),
                  constraints: BoxConstraints(
                    minWidth: 14,
                    minHeight: 14,
                  ),
                  child: Text(
                    '$notificationCount',
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 8,
                    ),
                    textAlign: TextAlign.center,
                  ),
                ),
              )
            : Positioned(
                right: 11,
                top: 11,
                child: Container(
                  constraints: BoxConstraints(
                    minWidth: 14,
                    minHeight: 14,
                  ),
                ),
              ),
      ],
    );
  }
}
