import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/models/vital_sign.dart';

class SCIBPChart extends StatelessWidget {
  final List<VitalSignData> systolic;
  final List<VitalSignData> diastolic;
  final int ageInDay;

  const SCIBPChart({
    @required this.systolic,
    @required this.diastolic,
    @required this.ageInDay,
  });

  double batasAtas(int ageInDay) {
    if (ageInDay <= 30) {
      return 110.0;
    } else if (ageInDay <= 122 && ageInDay > 30) {
      return 120.0;
    } else if (ageInDay <= 366 && ageInDay > 122) {
      return 130.0;
    } else if (ageInDay <= 1830 && ageInDay > 366) {
      return 140.0;
    } else if (ageInDay <= 4381 && ageInDay > 1830) {
      return 150.0;
    } else if (ageInDay <= 6589 && ageInDay > 4381) {
      return 220.0;
    } else {
      return 220.0;
    }
  }

  double batasBawah(int ageInDay) {
    if (ageInDay <= 30) {
      return 45.0;
    } else if (ageInDay <= 122 && ageInDay > 30) {
      return 60.0;
    } else if (ageInDay <= 366 && ageInDay > 122) {
      return 70.0;
    } else if (ageInDay <= 1830 && ageInDay > 366) {
      return 80.0;
    } else if (ageInDay <= 4381 && ageInDay > 1830) {
      return 90.0;
    } else if (ageInDay <= 6589 && ageInDay > 4381) {
      return 85.0;
    } else {
      return 85.0;
    }
  }

  @override
  Widget build(BuildContext context) {
    final double minX = systolic.first.createdDate.day.toDouble();
    final double maxX = systolic.last.createdDate.day.toDouble();

    return Column(
      children: <Widget>[
        Container(
          width: double.infinity,
          height: 200.0,
          child: LineChart(
            LineChartData(
              clipToBorder: false,
              gridData: FlGridData(horizontalInterval: 20.0),
              lineTouchData: LineTouchData(enabled: false),
              axisTitleData: FlAxisTitleData(
                show: true,
                topTitle: AxisTitle(
                  showTitle: true,
                  titleText: 'Blood Pressure',
                  textStyle: Theme.of(context).textTheme.headline,
                ),
              ),
              titlesData: FlTitlesData(
                bottomTitles: SideTitles(showTitles: false),
                leftTitles: SideTitles(
                  showTitles: true,
                  interval: 20.0,
                  margin: 10.0,
                  textStyle: Theme.of(context)
                      .textTheme
                      .caption
                      .copyWith(fontWeight: FontWeight.bold),
                  getTitles: (i) => '${i.toInt()}',
                ),
              ),
              borderData: FlBorderData(
                show: true,
                border: Border.all(
                  color: Colors.blue,
                  width: 3.0,
                ),
              ),
              minX: minX - 0.25,
              maxX: maxX + 1,
              minY: 20,
              maxY: 240,
              lineBarsData: [
                /// Batas atas
                LineChartBarData(
                  colors: [Colors.yellow.withOpacity(0.3)],
                  show: true,
                  spots: [
                    for (double i = minX - 0.25; i <= maxX + 1; i++)
                      FlSpot(i, batasAtas(ageInDay)),
                  ],
                  aboveBarData: BarAreaData(
                    show: true,
                    colors: [Colors.yellow.withOpacity(0.3)],
                  ),
                  dotData: FlDotData(
                    show: false,
                  ),
                ),

                /// Batas bawah
                LineChartBarData(
                  colors: [Colors.yellow.withOpacity(0.3)],
                  show: true,
                  spots: [
                    for (double i = minX - 0.25; i <= maxX + 1; i++)
                      FlSpot(i, batasBawah(ageInDay)),
                  ],
                  belowBarData: BarAreaData(
                    show: true,
                    colors: [Colors.yellow.withOpacity(0.3)],
                  ),
                  dotData: FlDotData(
                    show: false,
                  ),
                ),

                /// Systolic
                LineChartBarData(
                  dotData: FlDotData(dotColor: Colors.redAccent),
                  show: true,
                  barWidth: 2.0,
                  spots: systolic
                      .map(
                        (s) => FlSpot(
                          s.createdDate.day.toDouble(),
                          double.parse(s.value),
                        ),
                      )
                      .toList(),
                ),

                /// Diastolic
                LineChartBarData(
                  colors: [Colors.blue],
                  show: true,
                  barWidth: 2.0,
                  spots: diastolic
                      .map(
                        (d) => FlSpot(
                          d.createdDate.day.toDouble(),
                          double.parse(d.value),
                        ),
                      )
                      .toList(),
                ),
              ],
            ),
          ),
        ),
        SizedBox(height: 10.0),

        /// Legend
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Spacer(flex: 3),
            Text(
              'Systolic',
              style: Theme.of(context).textTheme.body2,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.redAccent,
            ),
            Spacer(),
            Text(
              'Diastolic',
              style: Theme.of(context).textTheme.body2,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.blue,
            ),
            Spacer(flex: 3)
          ],
        )
      ],
    );
  }
}
