import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/components/SCIAppTheme.dart';
import 'package:sci_mobile_components/src/models/field_content.dart';
import 'package:sci_mobile_components/src/models/theme_model.dart';

class SCIDetailField extends StatelessWidget {
  final String title;
  final List<FieldContent> content;
  final bool isWithButton;
  final VoidCallback onButtonPressed;
  final Widget buttonChild;

  SCIDetailField({
    this.title,
    this.content = const [],
    this.isWithButton = false,
    this.onButtonPressed,
    this.buttonChild = const Text('Open'),
  });

  @override
  Widget build(BuildContext context) {
    SCIThemeModel scitheme = SCIAppTheme.of(context).theme;

    return Column(
      children: <Widget>[
        Container(
          width: double.infinity,
          color: scitheme.primaryColor.withOpacity(0.2),
          padding: EdgeInsets.all(10.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                title,
                style: Theme.of(context)
                    .textTheme
                    .title
                    .copyWith(color: scitheme.darkColor),
              ),
              isWithButton
                  ? OutlineButton(
                      borderSide: BorderSide(color: scitheme.secondaryColor),
                      textColor: scitheme.secondaryColor,
                      child: Text('Open'),
                      onPressed: onButtonPressed,
                    )
                  : Container(),
            ],
          ),
        ),
        Container(
          padding: EdgeInsets.symmetric(vertical: 10.0, horizontal: 15.0),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: content
                .map(
                  (i) => Container(
                    padding: EdgeInsets.only(bottom: 20.0),
                    width: double.infinity,
                    height: 65.0,
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        Container(
                          alignment: Alignment.topLeft,
                          child: i.field,
                        ),
                        Container(
                          alignment: Alignment.centerLeft,
                          child: i.value,
                        ),
                      ],
                    ),
                  ),
                )
                .toList(),
          ),
        ),
      ],
    );
  }
}
