import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/components/SCIAppTheme.dart';
import 'package:sci_mobile_components/src/models/theme_model.dart';

class SCIOption extends StatelessWidget {
  final String label;
  final String value;
  final String fallbackValue;
  final VoidCallback onPressed;

  SCIOption({
    @required this.label,
    @required this.value,
    @required this.fallbackValue,
    @required this.onPressed,
  });

  @override
  Widget build(BuildContext context) {
    // Extract theme properties from top level SCIAppTheme
    final SCIThemeModel theme = SCIAppTheme.of(context).theme;

    return Column(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: <Widget>[
        Text(
          label,
          style: Theme.of(context).textTheme.subhead.copyWith(
                fontFamily: 'Overpass',
                color: theme.darkColor,
              ),
        ),
        SizedBox(
          height: 4.0,
        ),
        GestureDetector(
          onTap: () => onPressed(),
          child: Container(
            padding: EdgeInsets.symmetric(horizontal: 10.0),
            height: 45.0,
            decoration: BoxDecoration(
              color: Colors.grey[200],
              border: Border.all(
                color: value != null ? theme.primaryColor : Colors.grey,
                width: 2.0,
              ),
              borderRadius: BorderRadius.circular(4.0),
            ),
            alignment: Alignment.centerLeft,
            child: Text(
              value ?? fallbackValue,
              style: Theme.of(context).textTheme.title.copyWith(
                    fontFamily: 'Overpass',
                    color: value != null ? theme.primaryColor : Colors.grey,
                  ),
            ),
          ),
        ),
      ],
    );
  }
}

class SCIOptionDialog extends StatelessWidget {
  final int itemCount;
  final Function(BuildContext, int) itemBuilder;

  const SCIOptionDialog({
    @required this.itemCount,
    @required this.itemBuilder,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      child: Container(
        padding: EdgeInsets.all(10.0),
        height: 400.0,
        child: ListView.separated(
          itemCount: itemCount,
          separatorBuilder: (BuildContext c, int idx) =>
              Divider(thickness: 1.0),
          itemBuilder: itemBuilder,
        ),
      ),
    );
  }
}
